@@ -1,3 +1,12 @@
+# $Id: GetInfoType.pm 2488 2006-02-07 22:24:43Z timbo $
+#
+# Copyright (c) 2002  Tim Bunce  Ireland
+#
+# Constant data describing info type codes for the DBI getinfo function.
+#
+# You may distribute under the terms of either the GNU General Public
+# License or the Artistic License, as specified in the Perl README file.
+
 package DBI::Const::GetInfoType;
 
 use strict;
@@ -9,14 +18,19 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %GetInfoType);
 @ISA = qw(Exporter);
 @EXPORT = qw(%GetInfoType);
 
+my
+$VERSION = sprintf "%d.%02d", '$Revision: 1.5 $ ' =~ /(\d+)\.(\d+)/;
+
 =head1 NAME
- 
+
 DBI::Const::GetInfoType - Data describing GetInfo type codes
- 
+
 =head1 SYNOPSIS
 
   use DBI::Const::GetInfoType;
 
+=head1 DESCRIPTION
+
 Imports a %GetInfoType hash which maps names for GetInfo Type Codes
 into their corresponding numeric values. For example:
 
